@@ -294,9 +294,10 @@ class FreightMetricsSeriesUnit(Enum):
 
 class FreightMetricsSeriesStatus(Enum):
     """Status of vessels for freight metrics series"""
-    Ballast = "ballast"
-    Loaded = "loaded"
-    All = "all"
+
+    Ballast = "ballast"  #:
+    Loaded = "loaded"  #:
+    All = "all"  #:
 
 
 class VesselTypesDry(Enum):
@@ -852,12 +853,15 @@ class ImportsSplit(Enum):
     CrudeQuality = "Crude Quality"  #:
 
     CrudeProductionRegion = "Crude Production Region"  #:
+
+
 class ImportsMetric(Enum):
     """"""
 
     Quantity = "Quantity"  #:
     APISulfur = "API Sulfur"  #:
 
+
 class ImportsGranularity(Enum):
     """"""
 
